Rule: In Particular
===================

.. toctree::

   rule_approval
   rule_baldwin
   rule_black
   rule_borda
   rule_bucklin_by_rounds
   rule_bucklin_instant
   rule_condorcet
   rule_coombs
   rule_copeland
   rule_irv
   rule_k_approval
   rule_kim_roush
   rule_majority_judgment
   rule_maximin
   rule_nanson
   rule_plurality
   rule_range_voting
   rule_ranked_pairs
   rule_schulze
   rule_simplified_dodgson
   rule_two_round
   rule_veto
